@@ -61,9 +61,6 @@ Ext.define('MP.desktop.App', {
         }
 
         me.modules = me.getModules();
-        if (me.modules) {
-            me.initModules(me.modules);
-        }
 
         desktopCfg = me.getDesktopConfig();
         me.desktop = Ext.create(me.desktopClass || 'MP.desktop.Desktop',
@@ -124,7 +121,7 @@ Ext.define('MP.desktop.App', {
         var me = this, modules = [];
 
         Ext.each(me.user.modules, function (module) {
-            modules.push(Ext.create(module, {}));
+            modules.push(Ext.create(module, {app: me}));
         });
 
         return modules;
@@ -242,13 +239,6 @@ Ext.define('MP.desktop.App', {
         return Ext.apply(cfg, me.taskbarConfig);
     },
 
-    initModules: function(modules) {
-        var me = this;
-        Ext.each(modules, function (module) {
-            module.app = me;
-        });
-    },
-
     getModule: function(id) {
         var ms = this.modules;
         for (var i = 0, len = ms.length; i < len; i++) {
