@@ -26,18 +26,22 @@ Ext.define('MP.desktop.Module', {
 
     /**
      * @cfg {String} iconCls
-     * The CSS class used to associate the icon to the menu entry
+     * The CSS class used to associate the icon to the menu entry.
      */
 
     /**
-     * @cfg {String} launcherText
+     * @cfg {String or Function} launcherText
      * The text used for the menu entry. If this is null the module
-     * won't appear in the menu.
+     * won't appear in the menu. This may be also a function, to allow
+     * lazy translation of the text: alternatively subclasses can simply
+     * override the getLauncherText() method.
      */
 
     /**
-     * @cfg {String} launcherTooltip
-     * The tooltip for the menu entry
+     * @cfg {String or Function} launcherTooltip
+     * The tooltip for the menu entry. This may be also a function, to allow
+     * lazy translation of the text: alternatively subclasses can simply
+     * override the getLauncherText() method.
      */
 
     /**
@@ -103,8 +107,8 @@ Ext.define('MP.desktop.Module', {
      *                   handler: me.createOrShowWindow,
      *                   scope: me,
      *                   iconCls: me.iconCls,
-     *                   text: me.launcherText,
-     *                   tooltip: me.launcherTooltip
+     *                   text: me.getLauncherText(),
+     *                   tooltip: me.getLauncherTooltip()
      *               }, {
      *                   text: "Subsubmenu",
      *                   menu: {
@@ -123,17 +127,34 @@ Ext.define('MP.desktop.Module', {
      *   }
      */
     createLauncher: function() {
-        var me = this;
-        if(me.launcherText) {
-            return {
-                iconCls: me.iconCls,
-                text: me.launcherText,
-                tooltip: me.launcherTooltip
-            };
+        var me = this, text = me.getLauncherText();
+
+        if(text) {
+            var tooltip = me.getLauncherTooltip();
+
+            return {iconCls: me.iconCls, text: text, tooltip: tooltip};
         } else
             return null;
     },
 
+    getLauncherText: function() {
+        var me = this;
+        var text = me.launcherText;
+
+        if(typeof text == 'function')
+            text = text.call(me);
+        return text;
+    },
+
+    getLauncherTooltip: function() {
+        var me = this;
+        var tooltip = me.launcherTooltip;
+
+        if(typeof tooltip == 'function')
+            tooltip = tooltip.call(me);
+        return tooltip;
+    },
+
     init: function() {
         var me = this;
         me.launcher = me.createLauncher();
@@ -169,7 +190,7 @@ Ext.define('MP.desktop.Module', {
      *           function(done, config) {
      *               win = desktop.createWindow({
      *                   id: me.id,
-     *                   title: me.launcherText,
+     *                   title: me.getLauncherText(),
      *                   items: [
      *                       config.Buildings,
      *                       config.Pads,
